@@ -11,12 +11,16 @@
 # under the License.
 
 import binascii
+import logging
+import os
 import os.path
 import random
 import subprocess
 
 from reno import defaults
 
+LOG = logging.getLogger(__name__)
+
 
 def get_notes_dir(args):
     """Return the path to the release notes directory."""
@@ -34,12 +38,22 @@ def get_random_string(nbytes=8):
         val = binascii.hexlify(os.urandom(nbytes)).decode('utf-8')
     except Exception as e:
         print('ERROR, perhaps urandom is not supported: %s' % e)
-        val = ''.join('%02x' % random.randrange(256)
-                      for i in range(nbytes))
+        val = u''.join(u'%02x' % random.randrange(256)
+                       for i in range(nbytes))
     return val
 
 
 def check_output(*args, **kwds):
     """Unicode-aware wrapper for subprocess.check_output"""
-    raw = subprocess.check_output(*args, **kwds)
-    return raw.decode('utf-8')
+    process = subprocess.Popen(stdout=subprocess.PIPE,
+                               stderr=subprocess.PIPE,
+                               *args, **kwds)
+    output, errors = process.communicate()
+    retcode = process.poll()
+    if errors:
+        LOG.debug('error output from (%s): %s',
+                  ' '.join(*args),
+                  errors.rstrip())
+    if retcode:
+        raise subprocess.CalledProcessError(retcode, args, output=output)
+    return output.decode('utf-8')
